/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

#include <cutter.h>

void test_nothing (void);

void startup (void);
void shutdown (void);

void
startup (void)
{
}

void
setup (void)
{
}

void
test_nothing (void)
{
}

void
teardown (void)
{
}

void
shutdown (void)
{
}

/*
vi:ts=4:nowrap:ai:expandtab:sw=4
*/
